import os
import yaml
import logging

class Logger:
    def __init__(self, config_path="config.yaml"):
        """
        Initialize the Logger class.
        
        Parameters:
        config_path (str): The path to the YAML configuration file.
        """
        self.config_path = config_path
        self.load_config()
        self.setup_logging()

    def load_config(self):
        """Load configuration from the YAML file."""
        if not os.path.exists(self.config_path):
            raise FileNotFoundError(f"Configuration file {self.config_path} not found.")
        
        with open(self.config_path, "r") as stream:
            try:
                self.config = yaml.safe_load(stream)
            except yaml.YAMLError as e:
                raise ValueError(f"Error reading YAML file: {e}")

        self.debug = self.config.get("debug", False)
        self.persona_name = os.environ.get("PERSONA", "Default")

    def setup_logging(self):
        """Setup logging based on the configuration."""
        log_level = logging.DEBUG if self.debug else logging.INFO
        logs_path = self.config.get("logs_path", "./logs")
        
        if not os.path.exists(logs_path):
            os.makedirs(logs_path)
        
        persona = self.config["personas"].get(self.persona_name, {})
        persona_full_name = persona.get("name", "Unknown")

        logging.basicConfig(
            filename=f"{logs_path}/client-chat-{persona_full_name}.log",
            level=log_level,
            format="%(asctime)s:%(levelname)s:%(message)s",
        )

        self.logger = logging.getLogger(persona_full_name)

    def log(self, level, message):
        """Log a message with a given severity level."""
        self.logger.log(level, message)

    def debug(self, msg, *args, **kwargs):
        """Log a message with severity 'DEBUG'."""
        self.logger.debug(msg, *args, **kwargs)

    def info(self, msg, *args, **kwargs):
        """Log a message with severity 'INFO'."""
        self.logger.info(msg, *args, **kwargs)

    def warning(self, msg, *args, **kwargs):
        """Log a message with severity 'WARNING'."""
        self.logger.warning(msg, *args, **kwargs)

    def error(self, msg, *args, **kwargs):
        """Log a message with severity 'ERROR'."""
        self.logger.error(msg, *args, **kwargs)

    def critical(self, msg, *args, **kwargs):
        """Log a message with severity 'CRITICAL'."""
        self.logger.critical(msg, *args, **kwargs)

# Example usage
if __name__ == "__main__":
    logger = Logger()
    logger.info("This is an info message.")
    logger.warning("This is a warning message.")
    logger.error("This is an error message.")



import unittest
from srt_core.config import Config

class TestConfig(unittest.TestCase):
    def test_initialization(self):
        config = Config()
        self.assertIsNotNone(config)

if __name__ == '__main__':
    unittest.main()



import os
import yaml


class Config:
    def __init__(self):
        # Load configuration from yaml file
        with open("config.yaml", "r") as stream:
            self.config = yaml.safe_load(stream)

        # Check for 'debugging' variable in yaml
        self.debug = self.config.get("debug", False)

        # From environment variables
        self.persona_name = os.environ.get("PERSONA", "Default")
        self.server_port = int(os.environ.get("PORT", 8650))
        self.server_name = os.environ.get("SERVER_NAME", "0.0.0.0")

        # Load provider configuration
        unspecified_key="<unspecified_key-from-srt_core-module>"
        self.openai_compatible_api_key = self.config.get("openai_compatible_api_key", unspecified_key)
        self.huggingface_api_key = self.config.get("huggingface_api_key", unspecified_key)

        self.default_llm_name = self.get_first_existing_value(
            ["default_llm", "llms.default"], "mistral"
        )
        self.summary_llm_name = self.get_first_existing_value(
            ["summary_llm", "llms.summary"], "llama3"
        )
        self.chat_llm_name = self.get_first_existing_value(
            ["chat_llm", "llms.chat"], "chatml"
        )
        self.load_provider_settings()

        # Load Agent Tools
        self.load_tools_config()
        self.load_embeddings_llm()

        # Load persona specific settings
        self.load_persona_settings()

    def get_first_existing_value(self, keys, default_value):
        for key in keys:
            parts = key.split(".")
            value = self.config
            try:
                for part in parts:
                    value = value[part]
                return value
            except KeyError:
                continue
        return default_value

    def load_llm_settings(self, llm_name):
        llm_config = self.config["llms"][llm_name]
        return {
            "type": llm_config["type"],
            "filename": llm_config["filename"],
            "huggingface": llm_config["huggingface"],
            "url": llm_config["url"],
            "agent_provider": llm_config["agent_provider"],
            "server_name": llm_config["server"],
            "max_tokens": llm_config["max_tokens"],
        }

    def set_llm_attributes(self, llm_prefix, llm_settings):
        setattr(self, f"{llm_prefix}_llm_type", llm_settings["type"])
        setattr(self, f"{llm_prefix}_llm_filename", llm_settings["filename"])
        setattr(self, f"{llm_prefix}_llm_huggingface", llm_settings["huggingface"])
        setattr(self, f"{llm_prefix}_llm_url", llm_settings["url"])
        setattr(
            self, f"{llm_prefix}_llm_agent_provider", llm_settings["agent_provider"]
        )
        setattr(self, f"{llm_prefix}_llm_server_name", llm_settings["server_name"])
        setattr(self, f"{llm_prefix}_llm_max_tokens", llm_settings["max_tokens"])

    def load_provider_settings(self):
        self.default_llm_settings = self.load_llm_settings(self.default_llm_name)
        self.summary_llm_settings = self.load_llm_settings(self.summary_llm_name)
        self.chat_llm_settings = self.load_llm_settings(self.chat_llm_name)

        self.set_llm_attributes("default", self.default_llm_settings)
        self.set_llm_attributes("summary", self.summary_llm_settings)
        self.set_llm_attributes("chat", self.chat_llm_settings)

    def load_embeddings_llm(self):
        self.embeddings_llm = self.get_first_existing_value(
            ["embeddings_llm", "llms.embeddings"], "BAAI/bge-small-en-v1.5"
        )

    def load_tools_config(self):
        self.tokens_per_summary = self.config["tokens_per_summary"]
        self.tokens_search_results = self.config["tokens_search_results"]
        self.number_of_search_results = self.config["number_of_search_results"]

    def load_persona_settings(self):
        persona = self.config["personas"][self.persona_name]
        self.persona_ui_theme = persona["theme"]
        self.persona_full_name = persona["name"]
        self.persona_app_title = persona["title"]
        self.persona_avatar_image = f"images/{persona['avatar']}"
        self.persona_description = persona["description"]
        self.persona_system_message = persona["system_message"]
        self.persona_prompt_message = persona["persona"]
        self.persona_topic_examples = persona["topic_examples"]
        self.persona_temperature = persona["temperature"]
        self.persona_preferences = persona["preferences"]


config = Config()



import unittest
from srt_core.utils import Logger

class TestLogger(unittest.TestCase):
    def test_initialization(self):
        logger = Logger()
        self.assertIsNotNone(logger)

if __name__ == '__main__':
    unittest.main()



from setuptools import setup, find_packages

setup(
    name='srt-core',
    version='0.1.14',
    packages=find_packages(include=['srt_core', 'srt_core.*']),
    install_requires=[
        'pyyaml',
    ],
    entry_points={
        'console_scripts': [
            'config-cli=srt_core.config.config:main',
            'logger-cli=srt_core.utils.logger:main',
        ],
    },
    author='Suparious',
    author_email='suparious@solidrust.net',
    description='SolidRusT Core Libraries',
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    url='https://github.com/SolidRusT/srt-core',
    classifiers=[
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
    ],
    python_requires='>=3.11',
)
